@@ -1,5 +1,7 @@
 var NAVTREEINDEX17 =
 {
+"classzypp_1_1HistoryLog.html#a39281bed802920a7646de4f5da1ab003":[3,0,10,122,7],
+"classzypp_1_1HistoryLog.html#a39281bed802920a7646de4f5da1ab003":[4,0,7,113,7],
 "classzypp_1_1HistoryLog.html#a3cd0552d0a48692934226b234edeb3de":[3,0,10,122,4],
 "classzypp_1_1HistoryLog.html#a3cd0552d0a48692934226b234edeb3de":[4,0,7,113,4],
 "classzypp_1_1HistoryLog.html#a560d6d0289f7104d37890479f3d2232e":[3,0,10,122,12],
@@ -247,7 +249,5 @@ var NAVTREEINDEX17 =
 "classzypp_1_1HistoryLogDataRepoUrlChange.html#aba05deb873e0741463ba1925391a89b2":[4,0,7,120,3],
 "classzypp_1_1HistoryLogDataRepoUrlChange.html#adc499fc859dee3365e3b3cf01b0ce364":[3,0,10,129,0],
 "classzypp_1_1HistoryLogDataRepoUrlChange.html#adc499fc859dee3365e3b3cf01b0ce364":[4,0,7,120,0],
-"classzypp_1_1HistoryLogDataRepoUrlChange.html#af70964bb0ba3d923f6d1ca12a6052bcc":[3,0,10,129,1],
-"classzypp_1_1HistoryLogDataRepoUrlChange.html#af70964bb0ba3d923f6d1ca12a6052bcc":[4,0,7,120,1],
-"classzypp_1_1HistoryLogDataStampCommand.html":[3,0,10,130]
+"classzypp_1_1HistoryLogDataRepoUrlChange.html#af70964bb0ba3d923f6d1ca12a6052bcc":[3,0,10,129,1]
 };
