@@ -1,5 +1,9 @@
 var NAVTREEINDEX61 =
 {
+"classzypp_1_1sat_1_1Queue.html#ad3f2582b830dc44f0dc0603a0276e818":[3,0,10,37,11,5],
+"classzypp_1_1sat_1_1Queue.html#ad3f2582b830dc44f0dc0603a0276e818":[4,0,7,31,12,5],
+"classzypp_1_1sat_1_1Queue.html#add53ada0f0d6e51693a02ad9bcec7695":[3,0,10,37,110],
+"classzypp_1_1sat_1_1Queue.html#add53ada0f0d6e51693a02ad9bcec7695":[3,0,10,37,11,31],
 "classzypp_1_1sat_1_1Queue.html#add53ada0f0d6e51693a02ad9bcec7695":[4,0,7,31,12,31],
 "classzypp_1_1sat_1_1Queue.html#ae2c07f4d37276d479125f12b0789e221":[3,0,10,37,11,19],
 "classzypp_1_1sat_1_1Queue.html#ae2c07f4d37276d479125f12b0789e221":[4,0,7,31,12,19],
@@ -245,9 +249,5 @@ var NAVTREEINDEX61 =
 "classzypp_1_1sat_1_1SolvIterMixin.html#a0dcd0f855f9bb9ea7340a16a454cf02f":[4,0,7,31,17,12],
 "classzypp_1_1sat_1_1SolvIterMixin.html#a1f5495035dfe6fa47c84cfd81874845d":[3,0,10,37,16,18],
 "classzypp_1_1sat_1_1SolvIterMixin.html#a1f5495035dfe6fa47c84cfd81874845d":[4,0,7,31,17,18],
-"classzypp_1_1sat_1_1SolvIterMixin.html#a28eee2871af84f52b59804acf7065075":[3,0,10,37,16,14],
-"classzypp_1_1sat_1_1SolvIterMixin.html#a28eee2871af84f52b59804acf7065075":[4,0,7,31,17,14],
-"classzypp_1_1sat_1_1SolvIterMixin.html#a29b8a3e773b5ace96ebf99ff5c2c532d":[3,0,10,37,16,2],
-"classzypp_1_1sat_1_1SolvIterMixin.html#a29b8a3e773b5ace96ebf99ff5c2c532d":[4,0,7,31,17,2],
-"classzypp_1_1sat_1_1SolvIterMixin.html#a50b8e3cca664277cb9570a7a4b6562aa":[3,0,10,37,16,11]
+"classzypp_1_1sat_1_1SolvIterMixin.html#a28eee2871af84f52b59804acf7065075":[3,0,10,37,16,14]
 };
