@@ -1,5 +1,7 @@
 var NAVTREEINDEX8 =
 {
+"classztui_1_1ansi_1_1Color.html#a782a2f501892bfd9b899ecdc6ca07053":[4,0,6,0,1,17],
+"classztui_1_1ansi_1_1Color.html#a804dad48aad7c6f85e617389b10df388":[3,0,9,0,1,5],
 "classztui_1_1ansi_1_1Color.html#a804dad48aad7c6f85e617389b10df388":[4,0,6,0,1,5],
 "classztui_1_1ansi_1_1Color.html#a804dad48aad7c6f85e617389b10df388a00a45cbfa72b32d297792d7c42e26d12":[3,0,9,0,1,5,0],
 "classztui_1_1ansi_1_1Color.html#a804dad48aad7c6f85e617389b10df388a00a45cbfa72b32d297792d7c42e26d12":[4,0,6,0,1,5,0],
@@ -247,7 +249,5 @@ var NAVTREEINDEX8 =
 "classztui_1_1utf8_1_1string.html#a4568455d992c981c798e39d4c45d6de7":[4,0,6,5,0,4],
 "classztui_1_1utf8_1_1string.html#a4a4a4c0b650334f1213880fc06da3f82":[3,0,9,8,0,14],
 "classztui_1_1utf8_1_1string.html#a4a4a4c0b650334f1213880fc06da3f82":[4,0,6,5,0,14],
-"classztui_1_1utf8_1_1string.html#a5e7cf70a6ddc89ffbcbc56d1db622076":[3,0,9,8,0,2],
-"classztui_1_1utf8_1_1string.html#a5e7cf70a6ddc89ffbcbc56d1db622076":[4,0,6,5,0,2],
-"classztui_1_1utf8_1_1string.html#a64445f5d7db3d82d742b376c7b94e73e":[3,0,9,8,0,9]
+"classztui_1_1utf8_1_1string.html#a5e7cf70a6ddc89ffbcbc56d1db622076":[3,0,9,8,0,2]
 };
